@@ -1,3 +1,10 @@
+"""
+This submodule contains several quantization methods that can be used with our quantized layers to
+build quantized models.
+
+If you want to implement a new function, use the :code:`Quantization` base class as superclass.
+"""
+
 from typing import List, Type
 
 from .base import Quantization
